import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;

/**
 * An example MIDlet with simple "Hello" text and an Exit command.
 * Refer to the startApp, pauseApp, and destroyApp
 * methods so see how each handles the requested transition.
 */
public class HelloMidlet extends MIDlet implements CommandListener
{
	// Initialze the Midlet Display variable
    private Display midletDisplay;

    // Initialize a variable for the doneCommand
    private Command doneCommand;

	/**
	 * Initialize the Midlet variables at the start of its lifecycle
	 */
    public HelloMidlet()
    {
		System.out.println("\nConstructor");

		// Retrieve the display from the static display object
        midletDisplay = Display.getDisplay(this);

        // Initialize the doneCommand
		doneCommand = new Command("DONE", Command.SCREEN, 1);
    }

    /**
     * Creating the Hello Midlet World TextBox and associate
     * the exit command and listener.
     */
    public void startApp()
    {
		System.out.println("startApp()");

		// Create the TextBox containing the "Hello Midlet World!!" message
        TextBox textBox = new TextBox("Hello Midlet", "Hello Midlet World!!", 256, 0);

		// Add the done Command to the TextBox
        textBox.addCommand(doneCommand);

        // Set the command listener for the textbox to the current midlet
        textBox.setCommandListener( (CommandListener) this);

		// Set the current display of the midlet to the textBox screen
        midletDisplay.setCurrent(textBox);
    }

    /**
     * PauseApp is used to suspend background activities and release
     * resources on the device when the midlet is not active.
     */
    public void pauseApp()
    {
		System.out.println("PauseApp()");
    }

    /**
     * DestroyApp is used to stop background activities and release
     * resources on the device when the midlet as the end of the midlet
     * lifecycle.
     */
    public void destroyApp(boolean unconditional)
    {
		System.out.println("destroyApp("+ unconditional +")");
    }

    /*
     * The commandAction method is implemented by this Midlet to
     * satisfy the CommandListener interface and handle the done action.
     */
    public void commandAction(Command command, Displayable screen)
    {
		System.out.println("commandAction");

		// If the command is the doneCommand
		if (command == doneCommand)
		{
			// Call the destroyApp method
	    	destroyApp(false);

	    	// Notify the midlet platform that the midlet has completed
	    	notifyDestroyed();
	    }
    }
}
